@@ -26,6 +26,9 @@ def main():
         )
         time.sleep(0.125)
 
+    while True:
+        time.sleep(1)
+
 
 if __name__ == "__main__":
     typer.run(main)
